@@ -1,9 +1,19 @@
 APP = "apigeecli"
 CMD = "apigee"
-__version__ = "0.34.1"
+__version__ = "0.36.0"
 description = (
     "Apigee Management API command-line interface with multi-factor authentication"
 )
+long_description = (
+    """Apigee Management API command-line interface with multi-factor authentication
+
+Getting Help:
+
+    Homepage: https://pypi.org/project/apigeecli/
+    Apigee Product Documentation: https://apidocs.apigee.com/management/apis
+    The Apigee Management API command-line interface documentation: https://mdelotavo.github.io/apigee-cli/
+    """
+)
 
 import json
 from os import getenv
